@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all functions
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,6 @@
 #include "openturns/NoHessian.hxx"
 #include "openturns/P1LagrangeEvaluation.hxx"
 #include "openturns/Log.hxx"
-#include "openturns/Os.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -411,6 +410,19 @@ Graph Function::draw(const Point & xMin,
   return getImplementation()->draw(xMin, xMax, pointNumber, scale);
 }
 
+/** Draw cross sections of the function assumed to have 1D output */
+GridLayout Function::drawCrossCuts(const Point & centralPoint,
+                                   const Point & xMin,
+                                   const Point & xMax,
+                                   const Indices & pointNumber,
+                                   const Bool withMonoDimensionalCuts,
+                                   const Bool isFilled,
+                                   const Scalar vMin,
+                                   const Scalar vMax) const
+{
+  return getImplementation()->drawCrossCuts(centralPoint, xMin, xMax, pointNumber, withMonoDimensionalCuts, isFilled, vMin, vMax);
+}
+
 void Function::setStopCallback(StopCallback callBack, void * state)
 {
   copyOnWrite();
