@@ -2,7 +2,7 @@
 /**
  *  @brief Cobyla is an actual implementation for OptimizationAlgorithmImplementation using the cobyla library
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -212,11 +212,12 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
   /* Convert the input vector to Point */
   Point inP(n);
   std::copy(x, x + n, inP.begin());
+  Point inClip(inP);
 
   const UnsignedInteger nbIneqConst = problem.getInequalityConstraint().getOutputDimension();
   const UnsignedInteger nbEqConst = problem.getEqualityConstraint().getOutputDimension();
   Point constraintValue(nbIneqConst + 2 * nbEqConst, -1.0);
-  static const Scalar cobylaMaxScalar(1.0e-6 * SpecFunc::MaxScalar);
+  static const Scalar cobylaMaxScalar(1.0e-6 * SpecFunc::Infinity);
 
   Point outP;
   try
@@ -226,7 +227,6 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
         throw InvalidArgumentException(HERE) << "Cobyla got a nan/inf input value";
 
     // evaluate the function on the clipped point (still penalized if outside the bounds)
-    Point inClip(inP);
     if (problem.hasBounds())
     {
       const Point lowerBound(problem.getBounds().getLowerBound());
@@ -235,9 +235,9 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
       for (UnsignedInteger i = 0; i < inP.getDimension(); ++ i)
       {
         if (problem.getBounds().getFiniteLowerBound()[i])
-          inClip[i] = std::max(inP[i], lowerBound[i] - maximumConstraintError);
+          inClip[i] = std::max(inClip[i], lowerBound[i] - maximumConstraintError);
         if (problem.getBounds().getFiniteUpperBound()[i])
-          inClip[i] = std::min(inP[i], upperBound[i] + maximumConstraintError);
+          inClip[i] = std::min(inClip[i], upperBound[i] + maximumConstraintError);
       }
     }
     outP = problem.getObjective().operator()(inClip);
@@ -245,14 +245,14 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
     if (std::isnan(outP[0]))
       throw InvalidArgumentException(HERE) << "Cobyla got a nan output value";
 
-    // cobyla freezes when dealing with SpecFunc::MaxScalar
+    // cobyla freezes when dealing with SpecFunc::Infinity
     if (outP[0] > cobylaMaxScalar) outP[0] = cobylaMaxScalar;
     if (outP[0] < -cobylaMaxScalar) outP[0] = -cobylaMaxScalar;
     *f = problem.isMinimization() ? outP[0] : -outP[0];
   }
   catch (const std::exception & exc)
   {
-    LOGWARN(OSS() << "Cobyla went to an abnormal point x=" << inP.__str__() << " y=" << outP.__str__() << " msg=" << exc.what());
+    LOGWARN(OSS() << "Cobyla went to an abnormal point x=" << inClip.__str__() << " y=" << outP.__str__() << " msg=" << exc.what());
 
     // penalize it
     *f = problem.isMinimization() ? cobylaMaxScalar : cobylaMaxScalar;
@@ -266,7 +266,7 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
   /* Compute the inequality constraints at inP */
   if (problem.hasInequalityConstraint())
   {
-    const Point constraintInequalityValue(problem.getInequalityConstraint().operator()(inP));
+    const Point constraintInequalityValue(problem.getInequalityConstraint().operator()(inClip));
     algorithm->inequalityConstraintHistory_.add(constraintInequalityValue);
     for(UnsignedInteger index = 0; index < nbIneqConst; ++index) constraintValue[index + shift] = constraintInequalityValue[index];
     shift += nbIneqConst;
@@ -275,7 +275,7 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
   /* Compute the equality constraints at inP */
   if (problem.hasEqualityConstraint())
   {
-    const Point constraintEqualityValue = problem.getEqualityConstraint().operator()(inP);
+    const Point constraintEqualityValue = problem.getEqualityConstraint().operator()(inClip);
     algorithm->equalityConstraintHistory_.add(constraintEqualityValue);
     for(UnsignedInteger index = 0; index < nbEqConst; ++index) constraintValue[index + shift] = constraintEqualityValue[index] + algorithm->getMaximumConstraintError();
     shift += nbEqConst;
@@ -328,16 +328,4 @@ int Cobyla::ComputeObjectiveAndConstraint(int n,
   return returnValue;
 }
 
-void Cobyla::setIgnoreFailure(const Bool ignoreFailure)
-{
-  LOGWARN(OSS() << "Cobyla.setIgnoreFailure is deprecated, use setCheckStatus");
-  setCheckStatus(!ignoreFailure);
-}
-
-Bool Cobyla::getIgnoreFailure() const
-{
-  LOGWARN(OSS() << "Cobyla.getIgnoreFailure is deprecated, use getCheckStatus");
-  return !getCheckStatus();
-}
-
 END_NAMESPACE_OPENTURNS
