@@ -2,7 +2,7 @@
 /**
  *  @brief The result of a chaos expansion
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,14 +19,14 @@
  *
  */
 #include "openturns/FunctionalChaosResult.hxx"
-#include "openturns/Os.hxx"
 #include "openturns/OSS.hxx"
-#include "openturns/Sample.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/ComposedFunction.hxx"
 #include "openturns/DualLinearCombinationFunction.hxx"
 #include "openturns/Curve.hxx"
-#include <unordered_map>
+#include "openturns/ConstantFunction.hxx"
+#include "openturns/DistributionTransformation.hxx"
+#include "openturns/Basis.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -62,7 +62,7 @@ FunctionalChaosResult::FunctionalChaosResult(const Sample & inputSample,
     const FunctionCollection & Psi_k,
     const Point & residuals,
     const Point & relativeErrors)
-  : MetaModelResult(inputSample, outputSample, Function(), residuals, relativeErrors)
+  : MetaModelResult(inputSample, outputSample, ConstantFunction(inputSample.getDimension(), Point(outputSample.getDimension())), residuals, relativeErrors)
   , distribution_(distribution)
   , transformation_(transformation)
   , inverseTransformation_(inverseTransformation)
@@ -71,8 +71,19 @@ FunctionalChaosResult::FunctionalChaosResult(const Sample & inputSample,
   , alpha_k_(alpha_k)
   , Psi_k_(Psi_k)
 {
-  // The composed meta model will be a dual linear combination
-  composedMetaModel_ = DualLinearCombinationFunction(Psi_k, alpha_k);
+  if (Psi_k.getSize() > 0)
+  {
+    // The composed meta model will be a dual linear combination
+    composedMetaModel_ = DualLinearCombinationFunction(Psi_k, alpha_k);
+  }
+  else
+  {
+    // The meta model is the null function
+    composedMetaModel_ = ConstantFunction(inputSample.getDimension(), Point(outputSample.getDimension()));
+    Psi_k_.add(orthogonalBasis.build(0));
+    alpha_k_ = Sample(1, outputSample.getDimension());
+    I_.add(0);
+  }
   if (transformation.getEvaluation().getImplementation()->getClassName() == "IdentityEvaluation")
     metaModel_ = composedMetaModel_;
   else
@@ -117,7 +128,15 @@ String FunctionalChaosResult::__repr_markdown__() const
 {
   OSS oss(false);
   const UnsignedInteger indicesSize = I_.getSize();
-  const EnumerateFunction enumerateFunction(orthogonalBasis_.getEnumerateFunction());
+  EnumerateFunction enumerateFunction;
+  try
+  {
+    enumerateFunction = orthogonalBasis_.getEnumerateFunction();
+  }
+  catch (const NotYetImplementedException &)
+  {
+  }
+
   const UnsignedInteger outputDimension = metaModel_.getOutputDimension();
   const UnsignedInteger inputDimension = distribution_.getDimension();
   oss << getClassName() << "\n"
@@ -307,6 +326,97 @@ void FunctionalChaosResult::setInvolvesModelSelection(const Bool involvesModelSe
   involvesModelSelection_ = involvesModelSelection;
 }
 
+/* Conditional expectation accessor */
+FunctionalChaosResult FunctionalChaosResult::getConditionalExpectation(const Indices & conditioningIndices) const
+{
+  // Get marginal input sample and distribution
+  const UnsignedInteger inputDimension = inputSample_.getDimension();
+  if (!conditioningIndices.check(inputDimension))
+    throw InvalidArgumentException(HERE) << "The conditioning indices must be in the range [0, dim-1] and must be different.";
+  const Sample inputSampleMarginal(inputSample_.getMarginal(conditioningIndices));
+  const Distribution inputDistributionMarginal(distribution_.getMarginal(conditioningIndices));
+
+  // Check independence
+  if (!distribution_.hasIndependentCopula())
+    throw InvalidArgumentException(HERE) << "FunctionalChaosResult can only compute the conditional expectation for an independent copula.";
+
+  // Create the conditioned orthogonal basis
+  if (!orthogonalBasis_.getImplementation()->isTensorProduct())
+    throw InvalidArgumentException(HERE) << "FunctionalChaosResult can only compute the conditional expectation for a tensor-product basis.";
+  const OrthogonalBasis orthogonalBasisMarginal(orthogonalBasis_.getImplementation()->getMarginal(conditioningIndices));
+
+  // Create the active transformation and its inverse
+  const Distribution measureMarginal(orthogonalBasisMarginal.getMeasure());
+  const DistributionTransformation transformationMarginal(inputDistributionMarginal, measureMarginal);
+  const DistributionTransformation inverseTransformationMarginal(transformationMarginal.inverse());
+
+  // Restrict the enumeration function
+  const EnumerateFunction enumerateFunction(orthogonalBasis_.getEnumerateFunction());
+  const EnumerateFunction enumerateFunctionMarginal(enumerateFunction.getMarginal(conditioningIndices));
+
+  // Condition the multi-indices (taking into account for model selection)
+  // Get the indices of active multi-indices in the reduced enumeration rule
+  Indices listOfActiveReducedIndices(0);  // In the reduced enumeration rule
+  Indices listOfActiveIndices(0);  // In the list of coefficients
+  const UnsignedInteger numberOfFunctions = Psi_k_.getSize();
+  for (UnsignedInteger k = 0; k < numberOfFunctions; ++k)
+  {
+    const Indices multiIndex(enumerateFunction(I_[k]));
+    // See if this function has active marginal indices only
+    bool isActive = true;
+    for (UnsignedInteger i = 0; i < inputDimension; ++i)
+      if (!(conditioningIndices.contains(i)) && multiIndex[i] > 0)
+      {
+        isActive = false;
+        break;
+      }
+    if (isActive)
+    {
+      listOfActiveIndices.add(k);
+      const UnsignedInteger activeDimension = conditioningIndices.getSize();
+      Indices activeMultiIndex(activeDimension);
+      UnsignedInteger localIndex = 0;
+      for (UnsignedInteger i = 0; i < inputDimension; ++i)
+        if (conditioningIndices.contains(i))
+        {
+          activeMultiIndex[localIndex] = multiIndex[i];
+          ++localIndex;
+        }
+      const UnsignedInteger activeIndice = enumerateFunctionMarginal.inverse(activeMultiIndex);
+      listOfActiveReducedIndices.add(activeIndice);
+    }
+  } // For k in the number of functions
+  const UnsignedInteger reducedActiveBasisDimension = listOfActiveReducedIndices.getSize();
+
+  // Compute active coefficients
+  const Sample activeCoefficients(alpha_k_.select(listOfActiveIndices));
+
+  // Get the conditioned functional basis
+  Basis activeReducedBasis(0);
+  for (UnsignedInteger k = 0; k < reducedActiveBasisDimension; ++k)
+  {
+    const UnsignedInteger activeIndice = listOfActiveReducedIndices[k];
+    const Function activeFunction(orthogonalBasisMarginal.build(activeIndice));
+    activeReducedBasis.add(activeFunction);
+  }
+
+  // Create the conditional expectation PCE
+  const FunctionalChaosResult conditionalPCE(
+    inputSampleMarginal,
+    outputSample_,
+    inputDistributionMarginal,
+    transformationMarginal,
+    inverseTransformationMarginal,
+    orthogonalBasisMarginal,
+    listOfActiveReducedIndices,
+    activeCoefficients,
+    activeReducedBasis,
+    residuals_,
+    relativeErrors_
+  );
+  return conditionalPCE;
+}
+
 /* Method save() stores the object through the StorageManager */
 void FunctionalChaosResult::save(Advocate & adv) const
 {
