@@ -3,7 +3,7 @@
  *  @brief EventSimulation is a generic view of simulation methods for computing
  * probabilities and related quantities by sampling and estimation
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -25,7 +25,6 @@
 #include "openturns/Log.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/Point.hxx"
-#include "openturns/ResourceMap.hxx"
 #include "openturns/Less.hxx"
 #include "openturns/Uniform.hxx"
 #include "openturns/IdentityFunction.hxx"
@@ -181,6 +180,7 @@ void EventSimulation::run()
 
     std::chrono::steady_clock::time_point t1 = std::chrono::steady_clock::now();
     const Scalar timeDuration = std::chrono::duration<Scalar>(t1 - t0).count();
+    result_.setTimeDuration(timeDuration);
     if ((getMaximumTimeDuration() > 0.0) && (timeDuration > getMaximumTimeDuration()))
     {
       LOGINFO(OSS() << "Maximum time exceeded");
@@ -199,10 +199,6 @@ void EventSimulation::run()
         LOGINFO(OSS() << "Stopped due to user");
     } // stopCallback
   } // while
-
-  std::chrono::steady_clock::time_point t1 = std::chrono::steady_clock::now();
-  const Scalar timeDuration = std::chrono::duration<Scalar>(t1 - t0).count();
-  result_.setTimeDuration(timeDuration);
 }
 
 /* Compute the block sample and the points that realized the event */
