@@ -2,7 +2,7 @@
 /**
  *  @brief The ProductDistribution distribution
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,7 +35,7 @@ static const Factory<ProductDistribution> Factory_ProductDistribution;
 
 /* Default constructor */
 ProductDistribution::ProductDistribution()
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , p_left_(new Uniform(0.0, 1.0))
   , p_right_(new Uniform(0.0, 1.0))
   , algo_()
@@ -49,7 +49,7 @@ ProductDistribution::ProductDistribution()
 /* Parameters constructor to use when the two bounds are finite */
 ProductDistribution::ProductDistribution(const Distribution & left,
     const Distribution & right)
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , p_left_(left.getImplementation())
   , p_right_(right.getImplementation())
   , algo_()
@@ -149,7 +149,7 @@ public:
     if (isZero_)
     {
       if (pdf0_ == 0.0) return 0.0;
-      if (absU == 0.0) return SpecFunc::MaxScalar;
+      if (absU == 0.0) return SpecFunc::Infinity;
       return value * pdf0_ / absU;
     }
     // x_ != 0
@@ -735,7 +735,7 @@ Complex ProductDistribution::computeCharacteristicFunction(const Scalar x) const
   const Scalar varLeft = p_left_->getCovariance()(0, 0);
   const Scalar varRight = p_right_->getCovariance()(0, 0);
   if (x * x * (varLeft + muLeft * muLeft + varRight + muRight * muRight) < 2.0 * SpecFunc::ScalarEpsilon) return Complex(1.0, -x * muLeft * muRight);
-  if (std::abs(x) > ResourceMap::GetAsScalar("ProductDistribution-LargeCharacteristicFunctionArgument")) return ContinuousDistribution::computeCharacteristicFunction(x);
+  if (std::abs(x) > ResourceMap::GetAsScalar("ProductDistribution-LargeCharacteristicFunctionArgument")) return DistributionImplementation::computeCharacteristicFunction(x);
   const Scalar aLeft = p_left_->getRange().getLowerBound()[0];
   const Scalar bLeft = p_left_->getRange().getUpperBound()[0];
   const CFKernelProductDistribution cfKernel(p_left_, p_right_, x);
@@ -855,7 +855,7 @@ void ProductDistribution::setLeft(const Distribution & left)
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
-  isParallel_ = p_left_->isParallel();
+  setParallel(p_left_->isParallel() && p_right_->isParallel());
   computeRange();
 }
 
@@ -873,7 +873,7 @@ void ProductDistribution::setRight(const Distribution & right)
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
-  isParallel_ = p_right_->isParallel();
+  setParallel(p_left_->isParallel() && p_right_->isParallel());
   computeRange();
 }
 
@@ -910,7 +910,7 @@ Point ProductDistribution::getSingularities() const
 /* Method save() stores the object through the StorageManager */
 void ProductDistribution::save(Advocate & adv) const
 {
-  ContinuousDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "left_", *p_left_ );
   adv.saveAttribute( "right_", *p_right_ );
 }
@@ -918,7 +918,7 @@ void ProductDistribution::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void ProductDistribution::load(Advocate & adv)
 {
-  ContinuousDistribution::load(adv);
+  DistributionImplementation::load(adv);
   Distribution left;
   adv.loadAttribute( "left_", left );
   p_left_ = left.getImplementation();
