@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for WeibullMin distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -75,13 +75,15 @@ WeibullMin WeibullMinFactory::buildMethodOfMoments(const Sample & sample) const
   const Point parameters = {mean, sigma, gamma};
   WeibullMin result(buildAsWeibullMin(WeibullMinMuSigma()(parameters)));
   result.setDescription(sample.getDescription());
+  adaptToKnownParameter(sample, &result);
   return result;
 }
 
 WeibullMin WeibullMinFactory::buildMethodOfLikelihoodMaximization(const Sample & sample) const
 {
   LOGINFO("in WeibullMinFactory, using likelihood maximization");
-  const MaximumLikelihoodFactory factory(buildMethodOfMoments(sample));
+  MaximumLikelihoodFactory factory(buildMethodOfMoments(sample));
+  factory.setKnownParameter(knownParameterIndices_, knownParameterValues_);
   return buildAsWeibullMin(factory.build(sample).getParameter());
 }
 
