@@ -2,6 +2,7 @@
 How to fill an area
 ===================
 """
+
 # sphinx_gallery_thumbnail_number = 2
 # %%
 
@@ -11,12 +12,11 @@ How to fill an area
 # %%
 import openturns as ot
 from openturns import viewer
-from matplotlib import pylab as plt
+from matplotlib import pyplot as plt
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
-# We generate a sample from a standard gaussian distribution.
+# We generate a sample from the standard Normal distribution.
 
 # %%
 dist = ot.Normal()
