@@ -2,10 +2,11 @@
 Viscous free fall: metamodel of a field function
 ================================================
 """
+
 # %%
 #
 # In this example, we present how to create the metamodel of a field function.
-# This examples considers the :ref:`free fall model <use-case-viscous-fall>`.
+# This example considers the :ref:`free fall model <use-case-viscous-fall>`.
 # We create the metamodel automatically using :class:`openturns.experimental.PointToFieldFunctionalChaosAlgorithm`
 # and then also with a manual approach:
 # We first compute the Karhunen-Loève decomposition of a sample of trajectories.
@@ -24,7 +25,6 @@ import openturns.experimental as otexp
 import openturns.viewer as otv
 from openturns.usecases import viscous_free_fall
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # Load the viscous free fall example.
@@ -35,7 +35,6 @@ model = vff.model
 # %%
 # Generate a training sample.
 size = 2000
-ot.RandomGenerator.SetSeed(0)
 inputSample = distribution.getSample(size)
 outputSample = model(inputSample)
 
@@ -84,7 +83,7 @@ view = otv.View(graph)
 
 # %%
 # Compute the sensitivity indices
-sensitivity = otexp.FieldFunctionalChaosSobolIndices(result)
+sensitivity = ot.FieldFunctionalChaosSobolIndices(result)
 s1 = sensitivity.getFirstOrderIndices()
 st = sensitivity.getTotalOrderIndices()
 
@@ -119,17 +118,17 @@ graph.setYTitle(r"$z$")
 view = otv.View(graph)
 
 # %%
-# We create the lifting function which takes coefficients of the K.-L. modes as inputs and returns the trajectories.
+# We create the lifting function which takes coefficients of the Karhunen-Loève (KL) modes as inputs and returns the trajectories.
 klLiftingFunction = ot.KarhunenLoeveLifting(klResult)
 
 # %%
-# The `project` method computes the projection of the output sample (i.e. the trajectories) onto the K.-L. modes.
+# The `project` method computes the projection of the output sample (i.e. the trajectories) onto the KL modes.
 outputSampleChaos = klResult.project(outputSample)
 
 # %%
-# step 2: compute the metamodel of the KL modes
+# Step 2: compute the metamodel of the KL modes
 
-# We create a polynomial chaos metamodel which takes the input sample and returns the K.-L. modes.
+# We create a polynomial chaos metamodel which takes the input sample and returns the KL modes.
 algo = ot.FunctionalChaosAlgorithm(inputSample, outputSampleChaos, distribution)
 algo.run()
 chaosMetamodel = algo.getResult().getMetaModel()
@@ -141,9 +140,5 @@ chaosMetamodel = algo.getResult().getMetaModel()
 # %%
 metaModel = ot.PointToFieldConnection(klLiftingFunction, chaosMetamodel)
 
-# %%
-# Reset ResourceMap
-ot.ResourceMap.Reload()
-
 # %%
 otv.View.ShowAll()
