@@ -1,23 +1,24 @@
 """
-Example of multi output Kriging on the fire satellite model
-===========================================================
+Example of multi output Gaussian Process Regression on the fire satellite model
+===============================================================================
 """
+
 # %%
-# This example aims to illustrate Kriging metamodel with several outputs on the fire satellite model.
+# This example aims to illustrate Gaussian Process Fitter (Kriging) metamodel with several outputs on the fire satellite model.
 
 
 # %%
 # Loading of the model
 # --------------------
 # This model involves 9 input variables and 3 output variables.
-# We load the :ref:`Fire satellite use case<use-case-firesatellite>`.
+# We load the :ref:`Fire satellite use case<use-case-fire-satellite>`.
 
 # %%
 import openturns as ot
-from openturns.usecases.fireSatellite_function import FireSatelliteModel
+from openturns.usecases.fire_satellite import FireSatelliteModel
 from openturns.viewer import View
+import openturns.experimental as otexp
 
-ot.Log.Show(ot.Log.NONE)
 
 m = FireSatelliteModel()
 
@@ -31,7 +32,7 @@ model = m.model
 # We also define the distribution of input variables to build the training and test sets.
 
 # %%
-inputDistribution = m.distributionX
+inputDistribution = m.inputDistribution
 
 
 # %%
@@ -40,7 +41,6 @@ inputDistribution = m.distributionX
 # We now generate the input and output training sets as 10 times the dimension of the input vector.
 
 # %%
-ot.RandomGenerator.SetSeed(0)
 experiment = ot.LHSExperiment(inputDistribution, 10 * m.dim)
 inputTrainingSet = experiment.generate()
 outputTrainingSet = model(inputTrainingSet)
@@ -64,8 +64,8 @@ basis = ot.Basis(
 
 # %%
 # We would like to have separate covariance models for the three outputs.
-# To do so, we use the `TensorizedCovarianceModel`.
-# For the purpose of illustration, we consider `MaternModel` for the first and third outputs, and `SquaredExponential` for the second output.
+# To do so, we use the :class:`~openturns.TensorizedCovarianceModel`.
+# For the purpose of illustration, we consider :class:`~openturns.MaternModel` for the first and third outputs, and :class:`~openturns.SquaredExponential` for the second output.
 
 # %%
 myCov1 = ot.MaternModel([1.0] * m.dim, 2.5)
@@ -75,9 +75,9 @@ myCov3 = ot.MaternModel([1.0] * m.dim, 2.5)
 covarianceModel = ot.TensorizedCovarianceModel([myCov1, myCov2, myCov3])
 
 # %%
-# The scaling of the data is really important when dealing with Kriging,
+# The scaling of the data is really important when dealing with GP fitter,
 # especially considering the domain definition of the input variables (the
-# altitude varies in order of 1e7 whereas the drag coefficient is around 1).
+# altitude varies in order of :math:`10^7` whereas the drag coefficient is around 1).
 # We thus define appropriate bounds for the training algorithm based on the
 # domain definition of each variable.
 
@@ -88,16 +88,32 @@ scaleOptimizationBounds = ot.Interval(
 )
 
 # %%
-# We can now define the scaled version of Kriging model.
-algo = ot.KrigingAlgorithm(inputTrainingSet, outputTrainingSet, covarianceModel, basis)
-algo.setOptimizationBounds(scaleOptimizationBounds)
-algo.setOptimizeParameters(True)
+# We can now define the scaled version of with GP fitter model.
+# First, we need to initialize the covariance model's parameters in accordance with the optimization bounds.
+covarianceModelParameters = (
+    0.5
+    * (
+        scaleOptimizationBounds.getUpperBound()
+        - scaleOptimizationBounds.getLowerBound()
+    )
+    + scaleOptimizationBounds.getLowerBound()
+)
+covarianceModel.setParameter(covarianceModelParameters)
+fitter_algo = otexp.GaussianProcessFitter(
+    inputTrainingSet, outputTrainingSet, covarianceModel, basis
+)
+fitter_algo.setOptimizationBounds(scaleOptimizationBounds)
+fitter_algo.setOptimizeParameters(True)
 
 # %%
 # We run the algorithm and get the metamodel.
-algo.run()
-result = algo.getResult()
-krigingMetamodel = result.getMetaModel()
+fitter_algo.run()
+fitter_result = fitter_algo.getResult()
+gpr_algo = otexp.GaussianProcessRegression(fitter_result)
+gpr_algo.run()
+gpr_result = gpr_algo.getResult()
+
+gprMetamodel = gpr_result.getMetaModel()
 
 # %%
 # Validation of metamodel
@@ -109,20 +125,20 @@ ot.RandomGenerator.SetSeed(1)
 experimentTest = ot.LHSExperiment(inputDistribution, 50 * m.dim)
 inputTestSet = experimentTest.generate()
 outputTestSet = model(inputTestSet)
-outputKriging = krigingMetamodel(inputTestSet)
 
 # %%
-# Then, we use the `MetaModelValidation` class to validate the metamodel.
-val = ot.MetaModelValidation(outputTestSet, krigingMetamodel(inputTestSet))
+# Then, we use the :class:`~openturns.MetaModelValidation` class to validate the metamodel.
+metamodelPredictions = gprMetamodel(inputTestSet)
+val = ot.MetaModelValidation(outputTestSet, metamodelPredictions)
 
-R2 = val.computeR2Score()
+r2Score = val.computeR2Score()
 
 label = ["Total torque", "Total power", "Solar array area"]
 
 for i in range(3):
     graph = val.drawValidation().getGraph(0, i)
     graph.setLegends([""])
-    graph.setLegends(["R2 = %.2f%%" % (100 * R2[i]), ""])
+    graph.setLegends(["R2 = %.2f%%" % (100 * r2Score[i]), ""])
     graph.setLegendPosition("upper left")
     graph.setXTitle("Exact function")
     graph.setYTitle("Metamodel prediction")
